@@ -38,7 +38,7 @@ no warnings;
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( descend prepareblank ); # our @EXPORT = qw( );
 
-$VERSION = '0.123'; # our $VERSION = '';
+$VERSION = '0.127'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -1383,7 +1383,8 @@ sub descend
         }
         elsif ( ( $direction eq "<" ) or ( ( $direction eq "star"  ) and ( $starorder eq "<"  ) ) )
         {
-          $winnerentry = $lines[-1];
+          #$winnerentry = $lines[-1];
+          $winnerentry = $lines[0];
         }
         elsif ( ( $direction eq "=" ) or ( ( $direction eq "star"  ) and ( $starorder eq "="  ) ) )
         {
@@ -1529,7 +1530,8 @@ sub descend
         }
         elsif ( ( $direction eq "<" ) or ( ( $direction eq "star"  ) and ( $starorder eq "<"  ) ) )
         {
-          $winnerentry = $lines[-1];
+          #$winnerentry = $lines[-1];
+          $winnerentry = $lines[0];
         }
         elsif ( ( $direction eq "=" ) or ( ( $direction eq "star"  ) and ( $starorder eq "="  ) ) )
         {
