@@ -31,7 +31,7 @@ use Sim::OPT::Parcoord3d;
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
 
-$VERSION = '0.041';
+$VERSION = '0.043';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of nearest-neighbouring gradients weighted by distance.';
 
 #######################################################################
@@ -596,7 +596,7 @@ sub wei
   #say $tee "ARR VERY_BEFORE: " . dump(@arr);
   my %factlevels = %{ $factlevels_ref };  #say $tee "AND \%factlevels: " . dump( %factlevels );
   # my ( %magic, %wand, %spell, %bank );
-
+  $nfilter = ( $nfilter - 1 );
 
   sub fillbank
   { #say $tee "NOW IN FILLBANK.";
@@ -648,7 +648,8 @@ sub wei
                 my @sorteds = sort { $b <=> $a } @{ $bank{$trio}{strengths} };
                 if ( scalar( @sorteds ) > $nfilter )
                 {
-                  $benchmark = $sorteds[$nfilter-1];
+                  @sorteds = @sorteds[0..$nfilter]
+                  $benchmark = $sorteds[-1];
                 }
                 else
                 {
